@@ -1,5 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
+# @File    : util_cmd.py
+# @Time    : 2021-07-23
+# @Author  : Skypekey
+
 
 """Some functions related to command execution."""
 import subprocess
@@ -35,3 +39,7 @@ def get_out_text(cmd: List[str], encoding: str = "") -> Dict[str, Any]:
             "output_text": out_bytes.decode(encoding)
         }
     return out_text
+
+
+if __name__ == "__main__":
+    pass
