@@ -1,5 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
+# @File    : util_random.py
+# @Time    : 2021-07-23
+# @Author  : Skypekey
+
 
 """Custom random function."""
 import random
@@ -10,3 +14,7 @@ def random_str(string: str) -> str:
     list_str = list(string)
     random.shuffle(list_str)
     return "".join(list_str)
+
+
+if __name__ == "__main__":
+    pass
