@@ -1,5 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
+# @File    : util_time.py
+# @Time    : 2021-07-23
+# @Author  : Skypekey
+
 
 """Some functions related to time operations."""
 import time
@@ -34,3 +38,7 @@ def format_time(timestamp: float = NOW_TIME,
 
     tmp_time = time.localtime(timestamp)
     return time.strftime(format_str, tmp_time)
+
+
+if __name__ == "__main__":
+    pass
